@@ -17,8 +17,9 @@
 #######################################################################
 
 
-#' Find tautologies or "almost tautologies" in a dataset
+#' @title Find tautologies or "almost tautologies" in a dataset
 #'
+#' @description
 #' This function finds tautologies in a dataset, i.e., rules of the form
 #' `{a1 & a2 & ... & an} => {c}` where `a1`, `a2`, ..., `an` are
 #' antecedents and `c` is a consequent. The intent of searching for
@@ -56,20 +57,13 @@
 #'      (See Description for the definition of *support*.)
 #' @param min_confidence the minimum confidence of a rule in the dataset `x`.
 #'      (See Description for the definition of *confidence*.)
-#' @param contingency_table a logical value indicating whether to provide a contingency
+#' @param contingency_table (Deprecated.)
+#'      A logical value indicating whether to provide a contingency
 #'      table for each rule. If `TRUE`, the columns `pp`, `pn`, `np`, and `nn` are
 #'      added to the output table. These columns contain the number of rows satisfying
 #'      the antecedent and the consequent, the antecedent but not the consequent,
 #'      the consequent but not the antecedent, and neither the antecedent nor the
 #'      consequent, respectively.
-#' @param measures (Deprecated. Search for tautologies using
-#'      `dig_tautologies(contingency_table = TRUE)` and use the `add_interest()`
-#'      function on the result to compute additional measures.)
-#'      A character vector specifying the additional quality measures to compute.
-#'      If `NULL`, no additional measures are computed. Possible values are `"lift"`,
-#'      `"conviction"`, `"added_value"`.
-#'      See [https://mhahsler.github.io/arules/docs/measures](https://mhahsler.github.io/arules/docs/measures)
-#'      for a description of the measures.
 #' @param t_norm a t-norm used to compute conjunction of weights. It must be one of
 #'      `"goedel"` (minimum t-norm), `"goguen"` (product t-norm), or `"lukas"`
 #'      (Łukasiewicz t-norm).
@@ -85,6 +79,12 @@
 #'      classes and which is a tibble with found tautologies in the format equal to
 #'      the output of [dig_associations()].
 #' @author Michal Burda
+#' @examples
+#' d <- partition(mtcars, .breaks = 2)
+#' dig_tautologies(d,
+#'                 antecedent = everything(),
+#'                 consequent = everything(),
+#'                 min_confidence = 0.99)
 #' @export
 dig_tautologies <- function(x,
                             antecedent = everything(),
@@ -94,8 +94,7 @@ dig_tautologies <- function(x,
                             min_coverage = 0,
                             min_support = 0,
                             min_confidence = 0,
-                            contingency_table = FALSE,
-                            measures = deprecated(),
+                            contingency_table = deprecated(),
                             t_norm = "goguen",
                             max_results = Inf,
                             verbose = FALSE,
@@ -130,7 +129,6 @@ dig_tautologies <- function(x,
                                 min_support = min_support,
                                 min_confidence = min_confidence,
                                 contingency_table = contingency_table,
-                                measures = measures,
                                 t_norm = t_norm,
                                 max_results = maxres,
                                 verbose = verbose,
@@ -146,7 +144,6 @@ dig_tautologies <- function(x,
                                                      arg_min_support = "min_support",
                                                      arg_min_confidence = "min_confidence",
                                                      arg_contingency_table = "contingency_table",
-                                                     arg_measures = "measures",
                                                      arg_t_norm = "t_norm",
                                                      arg_max_results = "internal `maxres`",
                                                      arg_verbose = "verbose",
@@ -182,7 +179,6 @@ dig_tautologies <- function(x,
                             min_coverage = min_coverage,
                             min_support = min_support,
                             min_confidence = min_confidence,
-                            measures = measures,
                             t_norm = t_norm,
                             max_results = max_results,
                             verbose = verbose,
