@@ -17,9 +17,9 @@
 #######################################################################
 
 
-#' Convert columns of a data frame to Boolean or fuzzy sets
-#' (triangular, trapezoidal, or raised-cosine)
+#' @title Convert columns of a data frame to Boolean or fuzzy sets (triangular, trapezoidal, or raised-cosine)
 #'
+#' @description
 #' Transform selected columns of a data frame into either dummy logical
 #' variables or membership degrees of fuzzy sets, while leaving all remaining
 #' columns unchanged. Each transformed column typically produces multiple new
@@ -269,11 +269,18 @@ partition <- function(.data,
         x <- .data[[colindex]]
 
         if (all(is.na(x))) {
-            cli_abort(c("Unable to partition column {.var {colname}}.",
+            cli_abort(c("Unable to partition column {.var {colname}} because it contains only NA values.",
                        "i"="Column selected for partitioning must contain some non-NA values.",
                        "x"="Column {.var {colname}} is empty or all values are NA."),
                       call = call)
 
+        } else if (any(is.infinite(x))) {
+            positions <- which(is.infinite(x))
+            cli_abort(c("Unable to partition column {.var {colname}} because it contains infinite values.",
+                       "i"="Column selected for partitioning must not contain infinite values.",
+                       "x"="Column {.var {colname}} contains {length(positions)} infinite value{?s} at position{?s}: {paste(positions, collapse = ', ')}."),
+                      call = call)
+
         } else if (is.logical(x)) {
             res <- tibble(a = !is.na(x) & x,
                           b = !is.na(x) & !x)
