@@ -29,20 +29,20 @@ public:
     AntichainData()
     { }
 
-    AntichainData(List data)
+    AntichainData(const List& data)
     {
         for (R_xlen_t i = 0; i < data.size(); ++i) {
             addCondition(data[i]);
         }
     }
 
-    void addCondition(const IntegerVector& values)
+    inline void addCondition(const IntegerVector& values)
     { conditions.push_back(Condition(values)); }
 
-    const Condition& getCondition(size_t i) const
+    inline const Condition& getCondition(const size_t i) const
     { return conditions.at(i); }
 
-    size_t size() const
+    inline size_t size() const
     { return conditions.size(); }
 
 private:
