@@ -179,7 +179,6 @@ test_that("dig_tautologies argument forwarding and attributes", {
             max_length = 2,
             min_support = 0.1,
             min_confidence = 0.2,
-            measures = "lift",
             t_norm = "lukas",
             max_results = 5,
             verbose = FALSE,
@@ -200,7 +199,6 @@ test_that("dig_tautologies argument forwarding and attributes", {
     expect_equal(args$max_length, 2)
     expect_equal(args$min_support, 0.1)
     expect_equal(args$min_confidence, 0.2)
-    expect_equal(args$measures, "lift")
     expect_equal(args$t_norm, "lukas")
     expect_equal(args$max_results, 5)
     expect_true(is_tibble(res))
@@ -231,8 +229,6 @@ test_that("dig_tautologies handles invalid arguments", {
                  "`min_support` must be a double scalar.")
     expect_error(dig_tautologies(d, min_confidence = "x"),
                  "`min_confidence` must be a double scalar.")
-    expect_error(dig_tautologies(d, contingency_table = "x"),
-                 "`contingency_table` must be a flag.")
     expect_error(dig_tautologies(d, t_norm = "x"),
                  "`t_norm` must be equal to one of")
     expect_error(dig_tautologies(d, max_results = "x"),
